pub struct StringPool { /* private fields */ }Expand description
A pool for managing multiple PooledStrings.
Implementations
Sourceimpl StringPool
impl StringPool
Sourcepub fn with_max_size(max_size: usize) -> Self
pub fn with_max_size(max_size: usize) -> Self
Creates a StringPool with the specified max size.
Sourcepub fn store(&mut self, s: &str) -> PooledString
pub fn store(&mut self, s: &str) -> PooledString
Stores a string in the pool.
Sourcepub fn get_or_insert(&mut self, s: &str) -> PooledString
pub fn get_or_insert(&mut self, s: &str) -> PooledString
Gets a string from the pool or inserts it if not present.
Sourcepub fn total_capacity(&self) -> usize
pub fn total_capacity(&self) -> usize
Returns the total capacity of all strings in the pool.