pub struct ComponentRenderer { /* private fields */ }Expand description
Runtime component renderer that manages slot content and stack buffers.
Used during template rendering to accumulate and manage component content.
Implementations
Sourceimpl ComponentRenderer
impl ComponentRenderer
Sourcepub fn drain(&mut self, name: &str) -> String
pub fn drain(&mut self, name: &str) -> String
Drains and returns all content from a stack buffer, removing it.
Sourcepub fn peek(&self, name: &str) -> Option<String>
pub fn peek(&self, name: &str) -> Option<String>
Peeks at the content of a stack buffer without removing it.
Sourcepub fn set_slot_fill(&mut self, slot_name: &str, content: String)
pub fn set_slot_fill(&mut self, slot_name: &str, content: String)
Sets the fill content for a slot.
Sourcepub fn set_scoped_data(&mut self, slot_name: &str, key: &str, value: Value)
pub fn set_scoped_data(&mut self, slot_name: &str, key: &str, value: Value)
Sets scoped data for a slot.
Sourcepub fn get_scoped_data(&self, slot_name: &str) -> Option<HashMap<String, Value>>
pub fn get_scoped_data(&self, slot_name: &str) -> Option<HashMap<String, Value>>
Gets scoped data for a slot.